==> haskell-connection-0.2.8-9-i686.pkg.tar.xz: usr/share/haskell/register/haskell-connection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: connection
version: 0.2.8
id: connection-0.2.8-EyQru0LSmMy7hVxR3M6HRH
key: connection-0.2.8-EyQru0LSmMy7hVxR3M6HRH
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-connection
synopsis: Simple and easy network connections API
description:
    Simple network library for all your connection need.
    .
    Features: Really simple to use, SSL/TLS, SOCKS.
    .
    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.
category: Network
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Network.Connection
hidden-modules: Network.Connection.Types
abi: 3f2849672793986f043f601a50a48773
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/connection-0.2.8
library-dirs: /usr/lib/ghc-8.0.1/site-local/connection-0.2.8
data-dir: /usr/share/i386-linux-ghc-8.0.1/connection-0.2.8
hs-libraries: HSconnection-0.2.8-EyQru0LSmMy7hVxR3M6HRH
depends:
    base-4.9.0.0 byteable-0.1.1-15aIBCArSOBEnGxArzrDTM
    bytestring-0.10.8.1 containers-0.5.7.1
    data-default-class-0.1.2.0-6eetmQ6CbQOLoXb6k5kODu
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    socks-0.5.5-639qd4dP5FA2mjIZvcGBUX
    tls-1.3.10-Blcr4Z6u3dE5lnvWI6RAH7 x509-1.6.5-DTcGavhdY587qh4PDuwE2S
    x509-store-1.6.2-BXSkkYlpuOMCVOYYZxnB5x
    x509-system-1.6.4-JcNqX3QPwSbD82Y4Lr603r
    x509-validation-1.6.5-2z5ibMGuMw95SJnBJnL5Ua
haddock-interfaces: /usr/share/doc/haskell-connection/html/connection.haddock
haddock-html: /usr/share/doc/haskell-connection/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-connection-0.2.8-12-i686.pkg.tar.xz: usr/share/haskell/register/haskell-connection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: connection
version: 0.2.8
id: connection-0.2.8-A1jtQBZ3ycF6aQMdazfxZD
key: connection-0.2.8-A1jtQBZ3ycF6aQMdazfxZD
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-connection
synopsis: Simple and easy network connections API
description:
    Simple network library for all your connection need.
    .
    Features: Really simple to use, SSL/TLS, SOCKS.
    .
    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.
category: Network
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Network.Connection
hidden-modules: Network.Connection.Types
abi: d65e053896c49d971bbbfd58ba0d469d
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/connection-0.2.8
library-dirs: /usr/lib/ghc-8.0.1/site-local/connection-0.2.8
data-dir: /usr/share/i386-linux-ghc-8.0.1/connection-0.2.8
hs-libraries: HSconnection-0.2.8-A1jtQBZ3ycF6aQMdazfxZD
depends:
    base-4.9.0.0 byteable-0.1.1-15aIBCArSOBEnGxArzrDTM
    bytestring-0.10.8.1 containers-0.5.7.1
    data-default-class-0.1.2.0-6eetmQ6CbQOLoXb6k5kODu
    network-2.6.3.2-GMjPV5zpIjuBSljTanWiH
    socks-0.5.5-9ASlibOV22iGzYCtnf2aW5
    tls-1.3.10-8VIusEGpzG86Cx9zRJiKeH x509-1.6.5-8Gy5RyemL6zESXup4fdjNs
    x509-store-1.6.2-LFoPur4doeG38UepY0CX6A
    x509-system-1.6.4-Iw3kKvcD6fiDu0t687ezKP
    x509-validation-1.6.5-DllwiOn0JQV4eqKdKpyYX3
haddock-interfaces: /usr/share/doc/haskell-connection/html/connection.haddock
haddock-html: /usr/share/doc/haskell-connection/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
